@@ -12,72 +12,70 @@
 #include <level_zero/ze_api.h>
 
 namespace L0 {
-ze_result_t zeInit(
+ze_result_t ZE_APICALL zeInit(
     ze_init_flags_t flags) {
     return L0::init(flags);
 }
 
-ze_result_t zeInitDrivers(
+ze_result_t ZE_APICALL zeInitDrivers(
     uint32_t *pCount, ze_driver_handle_t *phDrivers, ze_init_driver_type_desc_t *desc) {
     return L0::initDrivers(pCount, phDrivers, desc);
 }
 
-ze_result_t zeDriverGet(
+ze_result_t ZE_APICALL zeDriverGet(
     uint32_t *pCount,
     ze_driver_handle_t *phDrivers) {
     return L0::Driver::get()->driverHandleGet(pCount, phDrivers);
 }
 
-ze_result_t zeDriverGetProperties(
+ze_result_t ZE_APICALL zeDriverGetProperties(
     ze_driver_handle_t hDriver,
     ze_driver_properties_t *pProperties) {
     return L0::DriverHandle::fromHandle(hDriver)->getProperties(pProperties);
 }
 
-ze_result_t zeDriverGetApiVersion(
+ze_result_t ZE_APICALL zeDriverGetApiVersion(
     ze_driver_handle_t hDriver,
     ze_api_version_t *version) {
     return L0::DriverHandle::fromHandle(hDriver)->getApiVersion(version);
 }
 
-ze_result_t zeDriverGetIpcProperties(
+ze_result_t ZE_APICALL zeDriverGetIpcProperties(
     ze_driver_handle_t hDriver,
     ze_driver_ipc_properties_t *pIPCProperties) {
     return L0::DriverHandle::fromHandle(hDriver)->getIPCProperties(pIPCProperties);
 }
 
-ze_result_t zeDriverGetLastErrorDescription(
+ze_result_t ZE_APICALL zeDriverGetLastErrorDescription(
     ze_driver_handle_t hDriver,
     const char **ppString) {
     return L0::DriverHandle::fromHandle(hDriver)->getErrorDescription(ppString);
 }
 
-ze_result_t zeDriverGetExtensionProperties(
+ze_result_t ZE_APICALL zeDriverGetExtensionProperties(
     ze_driver_handle_t hDriver,
     uint32_t *pCount,
     ze_driver_extension_properties_t *pExtensionProperties) {
     return L0::DriverHandle::fromHandle(hDriver)->getExtensionProperties(pCount, pExtensionProperties);
 }
 
-ze_result_t zeDriverGetExtensionFunctionAddress(
+ze_result_t ZE_APICALL zeDriverGetExtensionFunctionAddress(
     ze_driver_handle_t hDriver,
     const char *name,
     void **ppFunctionAddress) {
     return L0::BaseDriver::fromHandle(hDriver)->getExtensionFunctionAddress(name, ppFunctionAddress);
 }
 
-ze_context_handle_t zeDriverGetDefaultContext(
+ze_result_t ZE_APICALL zeDriverRTASFormatCompatibilityCheckExt(ze_driver_handle_t hDriver,
+                                                               ze_rtas_format_ext_t rtasFormatA,
+                                                               ze_rtas_format_ext_t rtasFormatB) {
+    return L0::DriverHandle::fromHandle(hDriver)->formatRTASCompatibilityCheckExt(rtasFormatA, rtasFormatB);
+}
+
+ze_context_handle_t ZE_APICALL zeDriverGetDefaultContext(
     ze_driver_handle_t hDriver) {
     return L0::DriverHandle::fromHandle(hDriver)->getDefaultContext();
 }
-
-ze_context_handle_t zerGetDefaultContext() {
-    return L0::DriverHandle::fromHandle(L0::globalDriverHandles->front())->getDefaultContext();
-}
-
-ze_result_t zerGetLastErrorDescription(const char **ppString) {
-    return L0::DriverHandle::fromHandle(L0::globalDriverHandles->front())->getErrorDescription(ppString);
-}
 } // namespace L0
 
 extern "C" {
@@ -153,15 +151,15 @@ ZE_APIEXPORT ze_result_t ZE_APICALL zeDriverGetExtensionFunctionAddress(
         ppFunctionAddress);
 }
 
-ze_context_handle_t ZE_APICALL zeDriverGetDefaultContext(
+ZE_APIEXPORT ze_result_t ZE_APICALL zeDriverRTASFormatCompatibilityCheckExt(
+    ze_driver_handle_t hDriver,
+    ze_rtas_format_ext_t rtasFormatA,
+    ze_rtas_format_ext_t rtasFormatB) {
+    return L0::zeDriverRTASFormatCompatibilityCheckExt(hDriver, rtasFormatA, rtasFormatB);
+}
+
+ZE_APIEXPORT ze_context_handle_t ZE_APICALL zeDriverGetDefaultContext(
     ze_driver_handle_t hDriver) {
     return L0::zeDriverGetDefaultContext(hDriver);
 }
-
-ZE_APIEXPORT ze_context_handle_t ZE_APICALL zerGetDefaultContext() {
-    return L0::zerGetDefaultContext();
-}
-ZE_APIEXPORT ze_result_t ZE_APICALL zerGetLastErrorDescription(const char **ppString) {
-    return L0::zerGetLastErrorDescription(ppString);
-}
 }
