@@ -9,9 +9,9 @@
 
 #include "shared/source/built_ins/built_ins.h"
 #include "shared/source/debug_settings/debug_settings_manager.h"
+#include "shared/source/device/device.h"
 #include "shared/source/execution_environment/execution_environment.h"
 #include "shared/source/helpers/compiler_product_helper.h"
-#include "shared/source/os_interface/os_interface.h"
 
 #include "level_zero/core/source/device/device.h"
 #include "level_zero/core/source/kernel/kernel.h"
@@ -53,6 +53,10 @@ void BuiltinFunctionsLibImpl::initBuiltinKernel(Builtin func) {
         kernelName = "CopyBufferRectBytes2dStateless";
         builtin = NEO::EBuiltInOps::copyBufferRectStateless;
         break;
+    case Builtin::copyBufferRectBytes2dStatelessHeapless:
+        kernelName = "CopyBufferRectBytes2dStateless";
+        builtin = NEO::EBuiltInOps::copyBufferRectStatelessHeapless;
+        break;
     case Builtin::copyBufferRectBytes3d:
         kernelName = "CopyBufferRectBytes3d";
         builtin = NEO::EBuiltInOps::copyBufferRect;
@@ -61,6 +65,10 @@ void BuiltinFunctionsLibImpl::initBuiltinKernel(Builtin func) {
         kernelName = "CopyBufferRectBytes3dStateless";
         builtin = NEO::EBuiltInOps::copyBufferRectStateless;
         break;
+    case Builtin::copyBufferRectBytes3dStatelessHeapless:
+        kernelName = "CopyBufferRectBytes3dStateless";
+        builtin = NEO::EBuiltInOps::copyBufferRectStatelessHeapless;
+        break;
     case Builtin::copyBufferToBufferMiddle:
         kernelName = "CopyBufferToBufferMiddleRegion";
         builtin = NEO::EBuiltInOps::copyBufferToBuffer;
@@ -170,14 +178,26 @@ void BuiltinFunctionsLibImpl::initBuiltinImageKernel(ImageBuiltin func) {
         builtinName = "CopyBufferToImage3d16Bytes";
         builtin = NEO::EBuiltInOps::copyBufferToImage3d;
         break;
+    case ImageBuiltin::copyBufferToImage3d16BytesAligned:
+        builtinName = "CopyBufferToImage3d16BytesAligned";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3d;
+        break;
     case ImageBuiltin::copyBufferToImage3d16BytesStateless:
         builtinName = "CopyBufferToImage3d16BytesStateless";
         builtin = NEO::EBuiltInOps::copyBufferToImage3dStateless;
         break;
+    case ImageBuiltin::copyBufferToImage3d16BytesAlignedStateless:
+        builtinName = "CopyBufferToImage3d16BytesAlignedStateless";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3dStateless;
+        break;
     case ImageBuiltin::copyBufferToImage3d16BytesHeapless:
         builtinName = "CopyBufferToImage3d16BytesStateless";
         builtin = NEO::EBuiltInOps::copyBufferToImage3dHeapless;
         break;
+    case ImageBuiltin::copyBufferToImage3d16BytesAlignedHeapless:
+        builtinName = "CopyBufferToImage3d16BytesAlignedStateless";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3dHeapless;
+        break;
     case ImageBuiltin::copyBufferToImage3d2Bytes:
         builtinName = "CopyBufferToImage3d2Bytes";
         builtin = NEO::EBuiltInOps::copyBufferToImage3d;
@@ -254,14 +274,26 @@ void BuiltinFunctionsLibImpl::initBuiltinImageKernel(ImageBuiltin func) {
         builtinName = "CopyImage3dToBuffer16Bytes";
         builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
         break;
+    case ImageBuiltin::copyImage3dToBuffer16BytesAligned:
+        builtinName = "CopyImage3dToBuffer16BytesAligned";
+        builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
+        break;
     case ImageBuiltin::copyImage3dToBuffer16BytesStateless:
         builtinName = "CopyImage3dToBuffer16BytesStateless";
         builtin = NEO::EBuiltInOps::copyImage3dToBufferStateless;
         break;
+    case ImageBuiltin::copyImage3dToBuffer16BytesAlignedStateless:
+        builtinName = "CopyImage3dToBuffer16BytesAlignedStateless";
+        builtin = NEO::EBuiltInOps::copyImage3dToBufferStateless;
+        break;
     case ImageBuiltin::copyImage3dToBuffer16BytesHeapless:
         builtinName = "CopyImage3dToBuffer16BytesStateless";
         builtin = NEO::EBuiltInOps::copyImage3dToBufferHeapless;
         break;
+    case ImageBuiltin::copyImage3dToBuffer16BytesAlignedHeapless:
+        builtinName = "CopyImage3dToBuffer16BytesAlignedStateless";
+        builtin = NEO::EBuiltInOps::copyImage3dToBufferHeapless;
+        break;
     case ImageBuiltin::copyImage3dToBuffer2Bytes:
         builtinName = "CopyImage3dToBuffer2Bytes";
         builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
