@@ -32,7 +32,6 @@
 
 #include <map>
 #include <optional>
-#include <unordered_map>
 #include <utility>
 #include <vector>
 
@@ -43,6 +42,8 @@ namespace NEO {
 class ScratchSpaceController;
 class TagNodeBase;
 struct EncodeDispatchKernelArgs;
+class CommandStreamReceiver;
+class GraphicsAllocation;
 } // namespace NEO
 
 namespace L0 {
@@ -53,6 +54,7 @@ struct Kernel;
 struct CommandQueue;
 struct CmdListKernelLaunchParams;
 struct CmdListMemoryCopyParams;
+struct CmdListHostFunctionParameters;
 
 struct CmdListReturnPoint {
     NEO::StreamProperties configSnapshot;
@@ -233,7 +235,8 @@ struct CommandList : _ze_command_list_handle_t {
                                            void *pNext,
                                            ze_event_handle_t hSignalEvent,
                                            uint32_t numWaitEvents,
-                                           ze_event_handle_t *phWaitEvents) = 0;
+                                           ze_event_handle_t *phWaitEvents,
+                                           CmdListHostFunctionParameters &parameters) = 0;
 
     static CommandList *create(uint32_t productFamily, Device *device, NEO::EngineGroupType engineGroupType,
                                ze_command_list_flags_t flags, ze_result_t &resultValue,
@@ -258,7 +261,9 @@ struct CommandList : _ze_command_list_handle_t {
 
     static ze_result_t setKernelState(Kernel *kernel, const ze_group_size_t groupSizes, void **arguments);
     static ze_result_t cloneAppendKernelExtensions(const ze_base_desc_t *desc, void *&outPnext);
-    static void freeClonedAppendKernelExtensions(void *outPnext);
+    static void freeClonedAppendKernelExtensions(void *pNext);
+    static ze_result_t cloneAppendMemoryCopyExtensions(const ze_base_desc_t *desc, void *&outPnext);
+    static void freeClonedAppendMemoryCopyExtensions(void *pNext);
 
     inline ze_command_list_handle_t toHandle() { return this; }
 
@@ -474,7 +479,7 @@ struct CommandList : _ze_command_list_handle_t {
         return closedCmdList;
     }
     ze_result_t obtainLaunchParamsFromExtensions(const ze_base_desc_t *desc, CmdListKernelLaunchParams &launchParams, ze_kernel_handle_t kernelHandle) const;
-    ze_result_t obtainMemoryCopyParamsFromExtensions(const ze_base_desc_t *desc, CmdListMemoryCopyParams &memoryCopyParams) const;
+    ze_result_t obtainMemoryCopyParamsFromExtensions(const ze_base_desc_t *desc, CmdListMemoryCopyParams &memoryCopyParams, bool writesOnly) const;
 
     void setCaptureTarget(Graph *graph) {
         this->captureTarget = graph;
@@ -484,13 +489,18 @@ struct CommandList : _ze_command_list_handle_t {
         return this->captureTarget;
     }
 
+    bool isCapturing() const {
+        return this->captureTarget != nullptr;
+    }
+
     Graph *releaseCaptureTarget() {
         return std::exchange(this->captureTarget, nullptr);
     }
 
     template <CaptureApi api, typename... TArgs>
     ze_result_t capture(TArgs... apiArgs) {
-        return L0::captureCommand<api>(*this, this->captureTarget, apiArgs...);
+        return this->isImmediateType() ? L0::captureCommand<api>(*this, this->captureTarget, apiArgs...)
+                                       : ZE_RESULT_ERROR_NOT_AVAILABLE;
     }
 
     inline bool getIsWalkerWithProfilingEnqueued() {
@@ -515,7 +525,7 @@ struct CommandList : _ze_command_list_handle_t {
         return flags;
     }
 
-    virtual void setPatchingPreamble(bool patching, bool saveWait) {}
+    void setPatchingPreamble(bool patching, bool saveWait);
 
     uint32_t getActiveScratchPatchElements() const {
         return activeScratchPatchElements;
@@ -535,6 +545,10 @@ struct CommandList : _ze_command_list_handle_t {
         return this->latestTaskCount;
     }
 
+    bool isInSynchronousMode() const {
+        return this->isSyncModeQueue;
+    }
+
   protected:
     virtual void dispatchHostFunction(void *pHostFunction,
                                       void *pUserData) = 0;
@@ -637,6 +651,7 @@ struct CommandList : _ze_command_list_handle_t {
     bool kernelWithAssertAppended = false;
     bool dispatchCmdListBatchBufferAsPrimary = false;
     bool copyThroughLockedPtrEnabled = false;
+    bool isSmallBarConfigPresent = false;
     bool useOnlyGlobalTimestamps = false;
     bool heaplessModeEnabled = false;
     bool heaplessStateInitEnabled = false;
