@@ -8,16 +8,17 @@
 #include "level_zero/core/source/cmdlist/cmdlist_imp.h"
 
 #include "shared/source/command_stream/command_stream_receiver.h"
-#include "shared/source/command_stream/linear_stream.h"
+#include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/device/device.h"
+#include "shared/source/helpers/cpu_copy_helper.h"
 #include "shared/source/helpers/engine_control.h"
 #include "shared/source/helpers/engine_node_helper.h"
 #include "shared/source/helpers/gfx_core_helper.h"
 #include "shared/source/helpers/hw_info.h"
-#include "shared/source/indirect_heap/indirect_heap.h"
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/os_interface/os_context.h"
 #include "shared/source/os_interface/os_time.h"
+#include "shared/source/utilities/tag_allocator.h"
 
 #include "level_zero/core/source/cmdqueue/cmdqueue.h"
 #include "level_zero/core/source/device/bcs_split.h"
@@ -26,20 +27,20 @@
 #include "level_zero/core/source/gfx_core_helpers/l0_gfx_core_helper.h"
 #include "level_zero/tools/source/metrics/metric.h"
 
-#include "neo_igfxfmid.h"
-
 #include <optional>
 
 namespace L0 {
 
-CommandList::CommandList(uint32_t numIddsPerBlock) : commandContainer(numIddsPerBlock) {
-    if (NEO::debugManager.flags.SplitBcsSize.get() != -1) {
-        this->minimalSizeForBcsSplit = NEO::debugManager.flags.SplitBcsSize.get() * MemoryConstants::kiloByte;
+CommandList::CommandList(uint32_t numIddsPerBlock) : commandContainer(numIddsPerBlock) {}
+
+void CommandList::setPatchingPreamble(bool patching, bool saveWait) {
+    if (isImmediateType()) {
+        cmdQImmediate->setPatchingPreamble(patching, saveWait);
     }
 }
 
-CommandListAllocatorFn commandListFactory[IGFX_MAX_PRODUCT] = {};
-CommandListAllocatorFn commandListFactoryImmediate[IGFX_MAX_PRODUCT] = {};
+CommandListAllocatorFn commandListFactory[NEO::maxProductEnumValue] = {};
+CommandListAllocatorFn commandListFactoryImmediate[NEO::maxProductEnumValue] = {};
 
 ze_result_t CommandListImp::destroy() {
     if (this->isBcsSplitNeeded) {
@@ -103,7 +104,7 @@ CommandList *CommandList::create(uint32_t productFamily, Device *device, NEO::En
                                  ze_command_list_flags_t flags, ze_result_t &returnValue,
                                  bool internalUsage) {
     CommandListAllocatorFn allocator = nullptr;
-    if (productFamily < IGFX_MAX_PRODUCT) {
+    if (productFamily < NEO::maxProductEnumValue) {
         allocator = commandListFactory[productFamily];
     }
 
@@ -169,7 +170,7 @@ CommandList *CommandList::createImmediate(uint32_t productFamily, Device *device
         cmdQdesc.mode = static_cast<ze_command_queue_mode_t>(overrideImmediateCmdListSyncMode);
     }
     CommandListAllocatorFn allocator = nullptr;
-    if (productFamily < IGFX_MAX_PRODUCT) {
+    if (productFamily < NEO::maxProductEnumValue) {
         allocator = commandListFactoryImmediate[productFamily];
     }
 
@@ -261,6 +262,7 @@ CommandList *CommandList::createImmediate(uint32_t productFamily, Device *device
     commandList->commandListPreemptionMode = device->getDevicePreemptionMode();
 
     commandList->copyThroughLockedPtrEnabled = gfxCoreHelper.copyThroughLockedPtrEnabled(hwInfo, productHelper);
+    commandList->isSmallBarConfigPresent = NEO::isSmallBarConfigPresent(device->getOsInterface());
 
     const bool cmdListSupportsCopyOffload = commandList->isInOrderExecutionEnabled() && !gfxCoreHelper.crossEngineCacheFlushRequired();
 
@@ -305,7 +307,7 @@ void CommandListImp::enableCopyOperationOffload() {
     NEO::CommandStreamReceiver *copyCsr = nullptr;
     uint32_t ordinal = static_cast<DeviceImp *>(device)->getCopyEngineOrdinal();
 
-    device->getCsrForOrdinalAndIndex(&copyCsr, ordinal, 0, immediateQueuePriority, 0, false);
+    device->getCsrForOrdinalAndIndex(&copyCsr, ordinal, 0, immediateQueuePriority, std::nullopt, false);
     UNRECOVERABLE_IF(!copyCsr);
 
     ze_command_queue_desc_t copyQueueDesc = {ZE_STRUCTURE_TYPE_COMMAND_QUEUE_DESC};
