@@ -153,10 +153,10 @@ ze_result_t ContextImp::allocHostMem(const ze_host_mem_alloc_desc_t *hostMemDesc
         return ZE_RESULT_SUCCESS;
     }
 
-    NEO::SVMAllocsManager::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::hostUnifiedMemory,
-                                                                           alignment,
-                                                                           this->rootDeviceIndices,
-                                                                           this->deviceBitfields);
+    NEO::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::hostUnifiedMemory,
+                                                         alignment,
+                                                         this->rootDeviceIndices,
+                                                         this->deviceBitfields);
 
     if (hostMemDesc->flags & ZE_HOST_MEM_ALLOC_FLAG_BIAS_UNCACHED) {
         unifiedMemoryProperties.allocationFlags.flags.locallyUncachedResource = 1;
@@ -177,10 +177,18 @@ ze_result_t ContextImp::allocHostMem(const ze_host_mem_alloc_desc_t *hostMemDesc
         return ZE_RESULT_ERROR_OUT_OF_HOST_MEMORY;
     }
 
-    if (false == lookupTable.exportMemory && this->driverHandle->usmHostMemAllocPool) {
-        if (auto usmPtrFromPool = this->driverHandle->usmHostMemAllocPool->createUnifiedMemoryAllocation(size, unifiedMemoryProperties)) {
-            *ptr = usmPtrFromPool;
-            return ZE_RESULT_SUCCESS;
+    if (false == lookupTable.exportMemory) {
+        this->driverHandle->initHostUsmAllocPoolOnce();
+        if (this->driverHandle->usmHostMemAllocPoolManager) {
+            if (auto usmPtrFromPool = this->driverHandle->usmHostMemAllocPoolManager->createUnifiedMemoryAllocation(size, unifiedMemoryProperties)) {
+                *ptr = usmPtrFromPool;
+                return ZE_RESULT_SUCCESS;
+            }
+        } else if (this->driverHandle->usmHostMemAllocPool) {
+            if (auto usmPtrFromPool = this->driverHandle->usmHostMemAllocPool->createUnifiedMemoryAllocation(size, unifiedMemoryProperties)) {
+                *ptr = usmPtrFromPool;
+                return ZE_RESULT_SUCCESS;
+            }
         }
     }
 
@@ -301,7 +309,7 @@ ze_result_t ContextImp::allocDeviceMem(ze_device_handle_t hDevice,
     }
 
     deviceBitfields[rootDeviceIndex] = neoDevice->getDeviceBitfield();
-    NEO::SVMAllocsManager::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::deviceUnifiedMemory, alignment, this->driverHandle->rootDeviceIndices, deviceBitfields);
+    NEO::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::deviceUnifiedMemory, alignment, this->driverHandle->rootDeviceIndices, deviceBitfields);
     unifiedMemoryProperties.allocationFlags.flags.shareableWithoutNTHandle = 0;
     auto &productHelper = neoDevice->getProductHelper();
     if (NEO::debugManager.flags.EnableShareableWithoutNTHandle.get()) {
@@ -320,6 +328,7 @@ ze_result_t ContextImp::allocDeviceMem(ze_device_handle_t hDevice,
     }
 
     if (false == lookupTable.exportMemory) {
+        this->driverHandle->initDeviceUsmAllocPoolOnce();
         if (neoDevice->getUsmMemAllocPoolsManager()) {
             if (auto usmPtrFromPool = neoDevice->getUsmMemAllocPoolsManager()->createUnifiedMemoryAllocation(size, unifiedMemoryProperties)) {
                 *ptr = usmPtrFromPool;
@@ -409,10 +418,10 @@ ze_result_t ContextImp::allocSharedMem(ze_device_handle_t hDevice,
         deviceBitfields[rootDeviceIndex] = neoDevice->getDeviceBitfield();
     }
 
-    NEO::SVMAllocsManager::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::sharedUnifiedMemory,
-                                                                           alignment,
-                                                                           this->rootDeviceIndices,
-                                                                           deviceBitfields);
+    NEO::UnifiedMemoryProperties unifiedMemoryProperties(InternalMemoryType::sharedUnifiedMemory,
+                                                         alignment,
+                                                         this->rootDeviceIndices,
+                                                         deviceBitfields);
     unifiedMemoryProperties.device = unifiedMemoryPropertiesDevice;
 
     if (deviceMemDesc->flags & ZE_DEVICE_MEM_ALLOC_FLAG_BIAS_UNCACHED) {
@@ -487,10 +496,8 @@ NEO::UsmMemAllocPool *ContextImp::getUsmPoolOwningPtr(const void *ptr, NEO::SvmA
     DEBUG_BREAK_IF(nullptr == svmData);
     NEO::UsmMemAllocPool *usmPool = nullptr;
 
-    if (InternalMemoryType::hostUnifiedMemory == svmData->memoryType &&
-        driverHandle->usmHostMemAllocPool &&
-        driverHandle->usmHostMemAllocPool->isInPool(ptr)) {
-        usmPool = driverHandle->usmHostMemAllocPool.get();
+    if (InternalMemoryType::hostUnifiedMemory == svmData->memoryType) {
+        usmPool = driverHandle->getHostUsmPoolOwningPtr(ptr);
     } else if (InternalMemoryType::deviceUnifiedMemory == svmData->memoryType) {
         usmPool = svmData->device->getUsmPoolOwningPtr(ptr);
     }
@@ -499,10 +506,13 @@ NEO::UsmMemAllocPool *ContextImp::getUsmPoolOwningPtr(const void *ptr, NEO::SvmA
 }
 
 bool ContextImp::tryFreeViaPooling(const void *ptr, NEO::SvmAllocationData *svmData, NEO::UsmMemAllocPool *usmPool) {
-    if (svmData->device && svmData->device->getUsmMemAllocPoolsManager()) {
-        return svmData->device->getUsmMemAllocPoolsManager()->freeSVMAlloc(ptr, false);
-    }
     if (usmPool) {
+        if (svmData->device && svmData->device->getUsmMemAllocPoolsManager()) {
+            return svmData->device->getUsmMemAllocPoolsManager()->freeSVMAlloc(ptr, false);
+        }
+        if (!svmData->device && driverHandle->usmHostMemAllocPoolManager) {
+            return driverHandle->usmHostMemAllocPoolManager->freeSVMAlloc(ptr, false);
+        }
         [[maybe_unused]] auto status = usmPool->freeSVMAlloc(ptr, false);
         DEBUG_BREAK_IF(false == status);
         return true;
@@ -701,6 +711,9 @@ ze_result_t ContextImp::evictImage(ze_device_handle_t hDevice, ze_image_handle_t
     NEO::Device *neoDevice = L0::Device::fromHandle(hDevice)->getNEODevice();
     NEO::MemoryOperationsHandler *memoryOperationsIface = neoDevice->getRootDeviceEnvironment().memoryOperationsInterface.get();
     auto success = memoryOperationsIface->evict(neoDevice, *alloc);
+    if (success == NEO::MemoryOperationsStatus::memoryNotFound) {
+        return ZE_RESULT_SUCCESS;
+    }
     if (implicitArgsAlloc) {
         memoryOperationsIface->evict(neoDevice, *implicitArgsAlloc);
     }
