@@ -243,6 +243,9 @@ DriverHandleImp::~DriverHandleImp() {
             if (this->usmHostMemAllocPool) {
                 this->usmHostMemAllocPool->cleanup();
             }
+            if (this->usmHostMemAllocPoolManager) {
+                this->usmHostMemAllocPoolManager->cleanup();
+            }
         }
     }
 
@@ -324,9 +327,12 @@ ze_result_t DriverHandleImp::initialize(std::vector<std::unique_ptr<NEO::Device>
     if (this->numDevices == 1) {
         this->svmAllocsManager->initUsmAllocationsCaches(*this->devices[0]->getNEODevice());
     }
-    this->initHostUsmAllocPool();
-    for (auto &device : this->devices) {
-        this->initDeviceUsmAllocPool(*device->getNEODevice(), this->numDevices > 1);
+    if (NEO::debugManager.flags.EnableUsmPoolLazyInit.get() != -1) {
+        this->lazyInitUsmPools = 1 == NEO::debugManager.flags.EnableUsmPoolLazyInit.get();
+    }
+    if (!this->lazyInitUsmPools) {
+        this->initHostUsmAllocPoolOnce();
+        this->initDeviceUsmAllocPoolOnce();
     }
 
     uuidTimestamp = static_cast<uint64_t>(std::chrono::system_clock::now().time_since_epoch().count());
@@ -371,7 +377,25 @@ DriverHandle *DriverHandle::create(std::vector<std::unique_ptr<NEO::Device>> dev
     return driverHandle;
 }
 
+void DriverHandleImp::initHostUsmAllocPoolOnce() {
+    std::call_once(this->hostUsmPoolOnceFlag, [this]() {
+        this->initHostUsmAllocPool();
+    });
+}
+
+void DriverHandleImp::initDeviceUsmAllocPoolOnce() {
+    std::call_once(this->deviceUsmPoolOnceFlag, [this]() {
+        for (auto &device : this->devices) {
+            this->initDeviceUsmAllocPool(*device->getNEODevice(), this->numDevices > 1);
+        }
+    });
+}
+
 void DriverHandleImp::initHostUsmAllocPool() {
+    bool useUsmPoolManager = true;
+    if (NEO::debugManager.flags.EnableUsmAllocationPoolManager.get() != -1) {
+        useUsmPoolManager = !!NEO::debugManager.flags.EnableUsmAllocationPoolManager.get();
+    }
     auto usmHostAllocPoolingEnabled = NEO::ApiSpecificConfig::isHostUsmPoolingEnabled();
     for (auto device : this->devices) {
         usmHostAllocPoolingEnabled &= device->getNEODevice()->getProductHelper().isHostUsmPoolAllocatorSupported() &&
@@ -384,10 +408,15 @@ void DriverHandleImp::initHostUsmAllocPool() {
         poolParams.poolSize = NEO::debugManager.flags.EnableHostUsmAllocationPool.get() * MemoryConstants::megaByte;
     }
     if (usmHostAllocPoolingEnabled) {
-        NEO::SVMAllocsManager::UnifiedMemoryProperties memoryProperties(InternalMemoryType::hostUnifiedMemory, MemoryConstants::pageSize2M,
-                                                                        rootDeviceIndices, deviceBitfields);
-        usmHostMemAllocPool.reset(new NEO::UsmMemAllocPool);
-        usmHostMemAllocPool->initialize(svmAllocsManager, memoryProperties, poolParams.poolSize, poolParams.minServicedSize, poolParams.maxServicedSize);
+        if (useUsmPoolManager) {
+            usmHostMemAllocPoolManager.reset(new NEO::UsmMemAllocPoolsManager(InternalMemoryType::hostUnifiedMemory, rootDeviceIndices, deviceBitfields, nullptr));
+            usmHostMemAllocPoolManager->initialize(this->svmAllocsManager);
+        } else {
+            NEO::UnifiedMemoryProperties memoryProperties(InternalMemoryType::hostUnifiedMemory, MemoryConstants::pageSize2M,
+                                                          rootDeviceIndices, deviceBitfields);
+            usmHostMemAllocPool.reset(new NEO::UsmMemAllocPool);
+            usmHostMemAllocPool->initialize(svmAllocsManager, memoryProperties, poolParams.poolSize, poolParams.minServicedSize, poolParams.maxServicedSize);
+        }
     }
 }
 
@@ -399,10 +428,10 @@ void DriverHandleImp::initDeviceUsmAllocPool(NEO::Device &device, bool multiDevi
     auto &hwInfo = device.getHardwareInfo();
     auto &l0GfxCoreHelper = device.getRootDeviceEnvironment().getHelper<L0GfxCoreHelper>();
     const bool compressionEnabledByDefault = l0GfxCoreHelper.usmCompressionSupported(hwInfo) && l0GfxCoreHelper.forceDefaultUsmCompressionSupport();
-    NEO::SVMAllocsManager::UnifiedMemoryProperties poolMemoryProperties(InternalMemoryType::deviceUnifiedMemory,
-                                                                        MemoryConstants::pageSize2M,
-                                                                        rootDeviceIndices,
-                                                                        deviceBitfields);
+    NEO::UnifiedMemoryProperties poolMemoryProperties(InternalMemoryType::deviceUnifiedMemory,
+                                                      MemoryConstants::pageSize2M,
+                                                      rootDeviceIndices,
+                                                      deviceBitfields);
     poolMemoryProperties.device = &device;
     poolMemoryProperties.allocationFlags.flags.compressedHint = compressionEnabledByDefault;
 
@@ -439,6 +468,15 @@ void DriverHandleImp::initDeviceUsmAllocPool(NEO::Device &device, bool multiDevi
     }
 }
 
+NEO::UsmMemAllocPool *DriverHandleImp::getHostUsmPoolOwningPtr(const void *ptr) {
+    if (usmHostMemAllocPoolManager) {
+        return usmHostMemAllocPoolManager->getPoolContainingAlloc(ptr);
+    } else if (usmHostMemAllocPool && usmHostMemAllocPool->isInPool(ptr)) {
+        return usmHostMemAllocPool.get();
+    }
+    return nullptr;
+}
+
 void DriverHandleImp::setupDevicesToExpose() {
 
     // If the user has requested FLAT or COMBINED device hierarchy model, then report all the sub devices as devices.
