@@ -13,11 +13,9 @@
 
 namespace L0 {
 
-FanImp::FanImp(OsSysman *pOsSysman) {
-    pOsFan = OsFan::create(pOsSysman);
+FanImp::FanImp(OsSysman *pOsSysman, uint32_t fanIndex, bool multipleFansSupported) {
+    pOsFan = OsFan::create(pOsSysman, fanIndex, multipleFansSupported);
     UNRECOVERABLE_IF(nullptr == pOsFan);
-
-    init();
 }
 
 ze_result_t FanImp::fanGetProperties(zes_fan_properties_t *pProperties) {
@@ -44,12 +42,6 @@ ze_result_t FanImp::fanGetState(zes_fan_speed_units_t units, int32_t *pSpeed) {
     return pOsFan->getState(units, pSpeed);
 }
 
-void FanImp::init() {
-    if (pOsFan->isFanModuleSupported()) {
-        this->initSuccess = true;
-    }
-}
-
 FanImp::~FanImp() = default;
 
 } // namespace L0
