@@ -24,9 +24,10 @@ class LinuxFanImp : public OsFan, NEO::NonCopyableAndNonMovableClass {
     ze_result_t setFixedSpeedMode(const zes_fan_speed_t *pSpeed) override;
     ze_result_t setSpeedTableMode(const zes_fan_speed_table_t *pSpeedTable) override;
     ze_result_t getState(zes_fan_speed_units_t units, int32_t *pSpeed) override;
-    bool isFanModuleSupported() override;
-    LinuxFanImp(OsSysman *pOsSysman);
+    LinuxFanImp(OsSysman *pOsSysman, uint32_t fanIndex, bool multipleFansSupported);
     LinuxFanImp() = default;
     ~LinuxFanImp() override = default;
+
+  protected:
 };
 } // namespace L0
