@@ -14,15 +14,14 @@
 #include "shared/source/execution_environment/root_device_environment.h"
 #include "shared/source/helpers/api_specific_config.h"
 #include "shared/source/helpers/get_info.h"
-#include "shared/source/helpers/hw_info.h"
 #include "shared/source/helpers/ptr_math.h"
 #include "shared/source/memory_manager/deferred_deleter.h"
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/memory_manager/unified_memory_manager.h"
+#include "shared/source/memory_manager/usm_pool_params.h"
 #include "shared/source/os_interface/device_factory.h"
 #include "shared/source/utilities/buffer_pool_allocator.inl"
 #include "shared/source/utilities/heap_allocator.h"
-#include "shared/source/utilities/staging_buffer_manager.h"
 #include "shared/source/utilities/tag_allocator.h"
 
 #include "opencl/source/cl_device/cl_device.h"
@@ -122,7 +121,19 @@ cl_int Context::tryGetExistingSvmAllocation(const void *ptr,
         SvmAllocationData *svmEntry = getSVMAllocsManager()->getSVMAlloc(ptr);
         if (svmEntry) {
             memoryType = svmEntry->memoryType;
-            if ((svmEntry->gpuAllocations.getGraphicsAllocation(rootDeviceIndex)->getGpuAddress() + svmEntry->size) < (castToUint64(ptr) + size)) {
+            UsmMemAllocPool *pool = nullptr;
+            if (this->getDevice(0u)->getPlatform()->getHostMemAllocPool().isInPool(ptr)) {
+                pool = &this->getDevice(0u)->getPlatform()->getHostMemAllocPool();
+            } else if (this->getDeviceMemAllocPool().isInPool(ptr)) {
+                pool = &this->getDeviceMemAllocPool();
+            }
+            if (pool) {
+                size_t pooledSize = pool->getPooledAllocationSize(ptr);
+                uint64_t pooledBasePtr = castToUint64(pool->getPooledAllocationBasePtr(ptr));
+                if ((pooledBasePtr + pooledSize) < (castToUint64(ptr) + size)) {
+                    return CL_INVALID_OPERATION;
+                }
+            } else if ((svmEntry->gpuAllocations.getGraphicsAllocation(rootDeviceIndex)->getGpuAddress() + svmEntry->size) < (castToUint64(ptr) + size)) {
                 return CL_INVALID_OPERATION;
             }
             allocation = svmEntry->cpuAllocation ? svmEntry->cpuAllocation : svmEntry->gpuAllocations.getGraphicsAllocation(rootDeviceIndex);
@@ -156,8 +167,9 @@ uint32_t Context::getMaxRootDeviceIndex() const {
 }
 
 CommandQueue *Context::getSpecialQueue(uint32_t rootDeviceIndex) {
-    if (specialQueues[rootDeviceIndex])
+    if (specialQueues[rootDeviceIndex]) {
         return specialQueues[rootDeviceIndex];
+    }
 
     static std::mutex mtx;
     std::lock_guard lock(mtx);
@@ -395,11 +407,7 @@ cl_int Context::getSupportedImageFormats(
     };
 
     if (flags & CL_MEM_READ_ONLY) {
-        if (this->getDevice(0)->getHardwareInfo().capabilityTable.supportsOcl21Features) {
-            appendImageFormats(SurfaceFormats::readOnly20());
-        } else {
-            appendImageFormats(SurfaceFormats::readOnly12());
-        }
+        appendImageFormats(SurfaceFormats::readOnly());
         if (Image::isImage2d(imageType) && nv12ExtensionEnabled) {
             appendImageFormats(SurfaceFormats::planarYuv());
         }
@@ -415,11 +423,7 @@ cl_int Context::getSupportedImageFormats(
             appendImageFormats(SurfaceFormats::readWriteDepth());
         }
     } else if (nv12ExtensionEnabled && (flags & CL_MEM_NO_ACCESS_INTEL)) {
-        if (this->getDevice(0)->getHardwareInfo().capabilityTable.supportsOcl21Features) {
-            appendImageFormats(SurfaceFormats::readOnly20());
-        } else {
-            appendImageFormats(SurfaceFormats::readOnly12());
-        }
+        appendImageFormats(SurfaceFormats::readOnly());
         if (Image::isImage2d(imageType)) {
             appendImageFormats(SurfaceFormats::planarYuv());
         }
@@ -532,8 +536,8 @@ void Context::initializeDeviceUsmAllocationPool() {
         auto subDeviceBitfields = getDeviceBitfields();
         auto &neoDevice = devices[0]->getDevice();
         subDeviceBitfields[neoDevice.getRootDeviceIndex()] = neoDevice.getDeviceBitfield();
-        SVMAllocsManager::UnifiedMemoryProperties memoryProperties(InternalMemoryType::deviceUnifiedMemory, MemoryConstants::pageSize2M,
-                                                                   getRootDeviceIndices(), subDeviceBitfields);
+        UnifiedMemoryProperties memoryProperties(InternalMemoryType::deviceUnifiedMemory, MemoryConstants::pageSize2M,
+                                                 getRootDeviceIndices(), subDeviceBitfields);
         memoryProperties.device = &neoDevice;
         usmDeviceMemAllocPool.initialize(svmMemoryManager, memoryProperties, usmDevicePoolParams.poolSize, usmDevicePoolParams.minServicedSize, usmDevicePoolParams.maxServicedSize);
     }
