@@ -18,6 +18,7 @@
 #include "shared/source/helpers/hw_info.h"
 #include "shared/source/helpers/local_memory_access_modes.h"
 #include "shared/source/helpers/memory_properties_helpers.h"
+#include "shared/source/helpers/patch_store_operation.h"
 #include "shared/source/memory_manager/allocation_properties.h"
 #include "shared/source/memory_manager/host_ptr_manager.h"
 #include "shared/source/memory_manager/memory_operations_handler.h"
@@ -212,7 +213,7 @@ bool inline copyHostPointer(Buffer *buffer,
     auto &productHelper = device.getProductHelper();
     auto memory = buffer->getGraphicsAllocation(rootDeviceIndex);
     auto isCompressionEnabled = memory->isCompressionEnabled();
-    const bool isLocalMemory = !MemoryPoolHelper::isSystemMemoryPool(memory->getMemoryPool());
+    const bool isLocalMemory = memory->isAllocatedInLocalMemoryPool();
     const bool gpuCopyRequired = isCompressionEnabled || isLocalMemory;
     if (gpuCopyRequired) {
         auto &hwInfo = device.getHardwareInfo();
@@ -448,6 +449,7 @@ Buffer *Buffer::create(Context *context,
                                                                                                    allocationInfo.allocateMemory, size, allocationInfo.allocationType, context->areMultiStorageAllocationsPreferred(),
                                                                                                    *hwInfo, context->getDeviceBitfieldForAllocation(rootDeviceIndex), context->isSingleDeviceContext());
             allocProperties.flags.preferCompressed = compressionEnabled;
+            allocProperties.flags.isHostInaccessibleAllocation = compressionEnabled;
             allocProperties.makeDeviceBufferLockable = bufferCreateArgs.makeAllocationLockable;
 
             if (allocationCpuPtr) {
@@ -723,15 +725,19 @@ bool Buffer::bufferRectPitchSet(const size_t *bufferOrigin,
                                 size_t &hostRowPitch,
                                 size_t &hostSlicePitch,
                                 bool isSrcBuffer) {
-    if (bufferRowPitch == 0)
+    if (bufferRowPitch == 0) {
         bufferRowPitch = region[0];
-    if (bufferSlicePitch == 0)
+    }
+    if (bufferSlicePitch == 0) {
         bufferSlicePitch = region[1] * bufferRowPitch;
+    }
 
-    if (hostRowPitch == 0)
+    if (hostRowPitch == 0) {
         hostRowPitch = region[0];
-    if (hostSlicePitch == 0)
+    }
+    if (hostSlicePitch == 0) {
         hostSlicePitch = region[1] * hostRowPitch;
+    }
 
     if (region[0] == 0 || region[1] == 0 || region[2] == 0) {
         return false;
