@@ -9,6 +9,7 @@
 
 #include "shared/source/command_container/implicit_scaling.h"
 #include "shared/source/command_stream/aub_subcapture_status.h"
+#include "shared/source/command_stream/host_function_worker_interface.h"
 #include "shared/source/command_stream/scratch_space_controller.h"
 #include "shared/source/command_stream/submission_status.h"
 #include "shared/source/command_stream/submissions_aggregator.h"
@@ -97,6 +98,7 @@ CommandStreamReceiver::CommandStreamReceiver(ExecutionEnvironment &executionEnvi
     auto &compilerProductHelper = rootDeviceEnvironment.getHelper<CompilerProductHelper>();
     this->heaplessModeEnabled = compilerProductHelper.isHeaplessModeEnabled(hwInfo);
     this->heaplessStateInitEnabled = compilerProductHelper.isHeaplessStateInitEnabled(heaplessModeEnabled);
+    this->hostFunctionWorkerMode = debugManager.flags.HostFunctionWorkMode.get();
 }
 
 CommandStreamReceiver::~CommandStreamReceiver() {
@@ -235,6 +237,25 @@ WaitStatus CommandStreamReceiver::waitForTaskCountAndCleanTemporaryAllocationLis
     return waitForTaskCountAndCleanAllocationList(requiredTaskCount, TEMPORARY_ALLOCATION);
 }
 
+void CommandStreamReceiver::createHostFunctionWorker() {
+
+    if (this->hostFunctionWorker != nullptr) {
+        return;
+    }
+
+    this->hostFunctionWorker = HostFunctionFactory::createHostFunctionWorker(this->hostFunctionWorkerMode,
+                                                                             this->isAubMode(),
+                                                                             this->downloadAllocationImpl,
+                                                                             this->getHostFunctionDataAllocation(),
+                                                                             &this->getHostFunctionData());
+
+    this->hostFunctionWorker->start();
+}
+
+IHostFunctionWorker *CommandStreamReceiver::getHostFunctionWorker() {
+    return this->hostFunctionWorker;
+}
+
 void CommandStreamReceiver::ensureCommandBufferAllocation(LinearStream &commandStream, size_t minimumRequiredSize, size_t additionalAllocationSize) {
     if (commandStream.getAvailableSpace() >= minimumRequiredSize) {
         return;
@@ -405,6 +426,10 @@ void CommandStreamReceiver::cleanupResources() {
         commandStream.replaceBuffer(nullptr, 0);
     }
 
+    if (hostFunctionWorker) {
+        cleanupHostFunctionWorker();
+    }
+
     if (tagsMultiAllocation) {
         // Null tag address to prevent waiting for tag update when freeing it
         tagAllocation = nullptr;
@@ -412,6 +437,8 @@ void CommandStreamReceiver::cleanupResources() {
         DEBUG_BREAK_IF(tagAllocation != nullptr);
         DEBUG_BREAK_IF(tagAddress != nullptr);
 
+        hostFunctionDataAllocation = nullptr;
+
         for (auto graphicsAllocation : tagsMultiAllocation->getGraphicsAllocations()) {
             getMemoryManager()->freeGraphicsMemory(graphicsAllocation);
         }
@@ -419,16 +446,6 @@ void CommandStreamReceiver::cleanupResources() {
         tagsMultiAllocation = nullptr;
     }
 
-    if (hostFunctionDataMultiAllocation) {
-        hostFunctionDataAllocation = nullptr;
-
-        for (auto graphicsAllocation : hostFunctionDataMultiAllocation->getGraphicsAllocations()) {
-            getMemoryManager()->freeGraphicsMemory(graphicsAllocation);
-        }
-        delete hostFunctionDataMultiAllocation;
-        hostFunctionDataMultiAllocation = nullptr;
-    }
-
     if (globalFenceAllocation) {
         getMemoryManager()->freeGraphicsMemory(globalFenceAllocation);
         globalFenceAllocation = nullptr;
@@ -464,6 +481,12 @@ void CommandStreamReceiver::cleanupResources() {
     ownedPrivateAllocations.clear();
 }
 
+void CommandStreamReceiver ::cleanupHostFunctionWorker() {
+    hostFunctionWorker->finish();
+    delete hostFunctionWorker;
+    hostFunctionWorker = nullptr;
+}
+
 WaitStatus CommandStreamReceiver::waitForCompletionWithTimeout(const WaitParams &params, TaskCountType taskCountToWait) {
     bool printWaitForCompletion = debugManager.flags.LogWaitingForCompletion.get();
     if (printWaitForCompletion) {
@@ -650,13 +673,6 @@ void CommandStreamReceiver::downloadAllocation(GraphicsAllocation &gfxAllocation
     }
 }
 
-void CommandStreamReceiver::startControllingDirectSubmissions() {
-    auto controller = this->executionEnvironment.directSubmissionController.get();
-    if (controller) {
-        controller->startControlling();
-    }
-}
-
 bool CommandStreamReceiver::enqueueWaitForPagingFence(uint64_t pagingFenceValue) {
     auto controller = this->executionEnvironment.directSubmissionController.get();
     if (this->isAnyDirectSubmissionEnabled() && controller) {
@@ -704,27 +720,41 @@ void *CommandStreamReceiver::getIndirectHeapCurrentPtr(IndirectHeapType heapType
     return nullptr;
 }
 
-void CommandStreamReceiver::ensureHostFunctionDataInitialization() {
-    if (!this->hostFunctionInitialized.load(std::memory_order_acquire)) {
-        initializeHostFunctionData();
+void CommandStreamReceiver::signalHostFunctionWorker() {
+    hostFunctionWorker->submit();
+}
+
+void CommandStreamReceiver::ensureHostFunctionWorkerStarted() {
+    if (!this->hostFunctionWorkerStarted.load(std::memory_order_acquire)) {
+        startHostFunctionWorker();
     }
 }
 
+void CommandStreamReceiver::startHostFunctionWorker() {
+    auto lock = obtainHostFunctionWorkerStartLock();
+    if (this->hostFunctionWorkerStarted.load(std::memory_order_relaxed)) {
+        return;
+    }
+
+    createHostFunctionWorker();
+
+    this->hostFunctionWorkerStarted.store(true, std::memory_order_release);
+}
+
 void CommandStreamReceiver::initializeHostFunctionData() {
 
-    auto lock = obtainUniqueOwnership();
+    auto tagAddress = this->tagAllocation->getUnderlyingBuffer();
 
-    if (this->hostFunctionInitialized.load(std::memory_order_relaxed)) {
-        return;
-    }
-    this->hostFunctionDataMultiAllocation = &this->createMultiAllocationInSystemMemoryPool(AllocationType::hostFunction);
-    this->hostFunctionDataAllocation = hostFunctionDataMultiAllocation->getGraphicsAllocation(rootDeviceIndex);
+    auto entryAddress = ptrOffset(tagAddress, HostFunctionHelper::entryOffset + TagAllocationLayout::hostFunctionDataOffset);
+    auto userDataAddress = ptrOffset(tagAddress, HostFunctionHelper::userDataOffset + TagAllocationLayout::hostFunctionDataOffset);
+    auto internalTagAddress = ptrOffset(tagAddress, HostFunctionHelper::internalTagOffset + TagAllocationLayout::hostFunctionDataOffset);
 
-    void *hostFunctionBuffer = hostFunctionDataAllocation->getUnderlyingBuffer();
-    this->hostFunctionData.entry = reinterpret_cast<decltype(HostFunctionData::entry)>(ptrOffset(hostFunctionBuffer, HostFunctionHelper::entryOffset));
-    this->hostFunctionData.userData = reinterpret_cast<decltype(HostFunctionData::userData)>(ptrOffset(hostFunctionBuffer, HostFunctionHelper::userDataOffset));
-    this->hostFunctionData.internalTag = reinterpret_cast<decltype(HostFunctionData::internalTag)>(ptrOffset(hostFunctionBuffer, HostFunctionHelper::internalTagOffset));
-    this->hostFunctionInitialized.store(true, std::memory_order_release);
+    this->hostFunctionData.entry = reinterpret_cast<uint64_t *>(entryAddress);
+    this->hostFunctionData.userData = reinterpret_cast<uint64_t *>(userDataAddress);
+    this->hostFunctionData.internalTag = reinterpret_cast<uint32_t *>(internalTagAddress);
+    *this->hostFunctionData.entry = 0;
+    *this->hostFunctionData.userData = 0;
+    *this->hostFunctionData.internalTag = 0;
 }
 
 HostFunctionData &CommandStreamReceiver::getHostFunctionData() {
@@ -732,7 +762,7 @@ HostFunctionData &CommandStreamReceiver::getHostFunctionData() {
 }
 
 GraphicsAllocation *CommandStreamReceiver::getHostFunctionDataAllocation() {
-    return hostFunctionDataAllocation;
+    return tagAllocation;
 }
 
 IndirectHeap &CommandStreamReceiver::getIndirectHeap(IndirectHeap::Type heapType,
@@ -866,10 +896,6 @@ void *CommandStreamReceiver::asyncDebugBreakConfirmation(void *arg) {
     return nullptr;
 }
 
-void CommandStreamReceiver::makeResidentHostFunctionAllocation() {
-    makeResident(*hostFunctionDataAllocation);
-}
-
 bool CommandStreamReceiver::initializeTagAllocation() {
     this->tagsMultiAllocation = &this->createMultiAllocationInSystemMemoryPool(AllocationType::tagBuffer);
 
@@ -906,6 +932,8 @@ bool CommandStreamReceiver::initializeTagAllocation() {
 
     this->barrierCountTagAddress = ptrOffset(this->tagAddress, TagAllocationLayout::barrierCountOffset);
 
+    initializeHostFunctionData();
+
     return true;
 }
 
@@ -975,12 +1003,18 @@ bool CommandStreamReceiver::createPreemptionAllocation() {
 std::unique_lock<CommandStreamReceiver::MutexType> CommandStreamReceiver::obtainUniqueOwnership() {
     return std::unique_lock<CommandStreamReceiver::MutexType>(this->ownershipMutex);
 }
+
 std::unique_lock<CommandStreamReceiver::MutexType> CommandStreamReceiver::tryObtainUniqueOwnership() {
     return std::unique_lock<CommandStreamReceiver::MutexType>(this->ownershipMutex, std::try_to_lock);
 }
 std::unique_lock<CommandStreamReceiver::MutexType> CommandStreamReceiver::obtainHostPtrSurfaceCreationLock() {
     return std::unique_lock<CommandStreamReceiver::MutexType>(this->hostPtrSurfaceCreationMutex);
 }
+
+std::unique_lock<CommandStreamReceiver::MutexType> CommandStreamReceiver::obtainHostFunctionWorkerStartLock() {
+    return std::unique_lock<CommandStreamReceiver::MutexType>(this->hostFunctionWorkerStartMutex);
+}
+
 AllocationsList &CommandStreamReceiver::getTemporaryAllocations() { return internalAllocationStorage->getTemporaryAllocations(); }
 AllocationsList &CommandStreamReceiver::getAllocationsForReuse() { return internalAllocationStorage->getAllocationsForReuse(); }
 AllocationsList &CommandStreamReceiver::getDeferredAllocations() { return internalAllocationStorage->getDeferredAllocations(); }
