@@ -67,6 +67,7 @@ class KmdNotifyHelper;
 class GfxCoreHelper;
 class ProductHelper;
 class ReleaseHelper;
+class IHostFunctionWorker;
 enum class WaitStatus;
 struct AubSubCaptureStatus;
 class SharedPoolAllocation;
@@ -148,6 +149,8 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     MOCKABLE_VIRTUAL WaitStatus waitForTaskCount(TaskCountType requiredTaskCount);
     WaitStatus waitForTaskCountAndCleanAllocationList(TaskCountType requiredTaskCount, uint32_t allocationUsage);
     MOCKABLE_VIRTUAL WaitStatus waitForTaskCountAndCleanTemporaryAllocationList(TaskCountType requiredTaskCount);
+    MOCKABLE_VIRTUAL void createHostFunctionWorker();
+    IHostFunctionWorker *getHostFunctionWorker();
 
     LinearStream &getCS(size_t minRequiredSize = 1024u);
     OSInterface *getOSInterface() const;
@@ -163,7 +166,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
         return tagsMultiAllocation;
     }
     MultiGraphicsAllocation &createMultiAllocationInSystemMemoryPool(AllocationType allocationType);
-    void makeResidentHostFunctionAllocation();
     TaskCountType getNextBarrierCount() { return this->barrierCount.fetch_add(1u); }
     TaskCountType peekBarrierCount() const { return this->barrierCount.load(); }
     volatile TagAddressType *getTagAddress() const { return tagAddress; }
@@ -270,7 +272,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     MOCKABLE_VIRTUAL bool createPerDssBackedBuffer(Device &device);
     [[nodiscard]] MOCKABLE_VIRTUAL std::unique_lock<MutexType> obtainUniqueOwnership();
     [[nodiscard]] MOCKABLE_VIRTUAL std::unique_lock<MutexType> tryObtainUniqueOwnership();
-
     bool peekTimestampPacketWriteEnabled() const { return timestampPacketWriteEnabled; }
 
     bool isLatestTaskCountFlushed() {
@@ -351,8 +352,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
 
     uint32_t getRootDeviceIndex() const { return rootDeviceIndex; }
 
-    MOCKABLE_VIRTUAL void startControllingDirectSubmissions();
-
     MOCKABLE_VIRTUAL bool isAnyDirectSubmissionEnabled() const {
         return this->isDirectSubmissionEnabled() || isBlitterDirectSubmissionEnabled();
     }
@@ -380,6 +379,8 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     }
 
     virtual void stopDirectSubmission(bool blocking, bool needsLock) {}
+    virtual void unregisterDirectSubmissionFromController(){};
+    virtual void resetDirectSubmission(){};
 
     virtual QueueThrottle getLastDirectSubmissionThrottle() = 0;
 
@@ -569,13 +570,16 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     bool isLatestFlushIsTaskCountUpdateOnly() const { return latestFlushIsTaskCountUpdateOnly; }
 
     MOCKABLE_VIRTUAL uint32_t getContextGroupId() const;
+    MOCKABLE_VIRTUAL void signalHostFunctionWorker();
 
-    void ensureHostFunctionDataInitialization();
+    void ensureHostFunctionWorkerStarted();
     HostFunctionData &getHostFunctionData();
     GraphicsAllocation *getHostFunctionDataAllocation();
+    [[nodiscard]] std::unique_lock<MutexType> obtainHostFunctionWorkerStartLock();
 
   protected:
-    MOCKABLE_VIRTUAL void initializeHostFunctionData();
+    void initializeHostFunctionData();
+    MOCKABLE_VIRTUAL void startHostFunctionWorker();
 
     virtual CompletionStamp flushTaskHeapless(LinearStream &commandStreamTask, size_t commandStreamTaskStart,
                                               const IndirectHeap *dsh, const IndirectHeap *ioh, const IndirectHeap *ssh,
@@ -586,6 +590,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
                                              TaskCountType taskLevel, DispatchFlags &dispatchFlags, Device &device) = 0;
 
     void cleanupResources();
+    void cleanupHostFunctionWorker();
     void printDeviceIndex();
     void checkForNewResources(TaskCountType submittedTaskCount, TaskCountType allocationTaskCount, GraphicsAllocation &gfxAllocation);
     bool checkImplicitFlushForGpuIdle();
@@ -612,6 +617,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     std::unique_ptr<TagAllocatorBase> timestampPacketAllocator;
     std::unique_ptr<Thread> userPauseConfirmation;
     std::unique_ptr<IndirectHeap> globalStatelessHeap;
+    IHostFunctionWorker *hostFunctionWorker = nullptr;
 
     ResidencyContainer residencyAllocations;
     PrivateAllocsToReuseContainer ownedPrivateAllocations;
@@ -619,6 +625,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     MutexType ownershipMutex;
     MutexType hostPtrSurfaceCreationMutex;
     MutexType registeredClientsMutex;
+    MutexType hostFunctionWorkerStartMutex;
     ExecutionEnvironment &executionEnvironment;
 
     LinearStream commandStream;
@@ -649,7 +656,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     GraphicsAllocation *globalStatelessHeapAllocation = nullptr;
 
     MultiGraphicsAllocation *tagsMultiAllocation = nullptr;
-    MultiGraphicsAllocation *hostFunctionDataMultiAllocation = nullptr;
     GraphicsAllocation *hostFunctionDataAllocation = nullptr;
     IndirectHeap *indirectHeap[IndirectHeapType::numTypes];
     OsContext *osContext = nullptr;
@@ -666,7 +672,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     std::atomic<TaskCountType> taskCount{0};
 
     std::atomic<uint32_t> numClients = 0u;
-
     DispatchMode dispatchMode = DispatchMode::immediateDispatch;
     SamplerCacheFlushState samplerCacheFlushRequired = SamplerCacheFlushState::samplerCacheFlushNotRequired;
     PreemptionMode lastPreemptionMode = PreemptionMode::Initial;
@@ -675,7 +680,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     uint32_t lastSentL3Config = 0;
     uint32_t latestSentStatelessMocsConfig;
     uint64_t lastSentSliceCount;
-
+    int32_t hostFunctionWorkerMode = -1;
     uint32_t requiredScratchSlot0Size = 0;
     uint32_t requiredScratchSlot1Size = 0;
     uint32_t lastAdditionalKernelExecInfo;
@@ -688,7 +693,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     TaskCountType completionFenceValue = 0;
     const uint32_t rootDeviceIndex;
     const DeviceBitfield deviceBitfield;
-    std::atomic<bool> hostFunctionInitialized = false;
+    std::atomic<bool> hostFunctionWorkerStarted = false;
     bool isPreambleSent = false;
     bool isStateSipSent = false;
     bool isEnginePrologueSent = false;
