@@ -93,6 +93,10 @@ Device::~Device() {
         usmGlobalSurfaceAllocPool->cleanup();
     }
 
+    if (this->getRootDeviceEnvironment().osInterface) {
+        this->getRootDeviceEnvironment().osInterface->unregisterTrimCallback();
+    }
+
     secondaryCsrs.clear();
     executionEnvironment->memoryManager->releaseSecondaryOsContexts(this->getRootDeviceIndex());
     commandStreamReceivers.clear();
@@ -393,10 +397,6 @@ bool Device::createEngines() {
 
             auto highPriorityContextCount = gfxCoreHelper.getContextGroupHpContextsCount(engineGroupType, hpEngineAvailable);
 
-            if (debugManager.flags.OverrideNumHighPriorityContexts.get() != -1) {
-                highPriorityContextCount = static_cast<uint32_t>(debugManager.flags.OverrideNumHighPriorityContexts.get());
-            }
-
             if (getRootDeviceEnvironment().osInterface && getRootDeviceEnvironment().osInterface->getAggregatedProcessCount() > 1) {
                 const auto numProcesses = getRootDeviceEnvironment().osInterface->getAggregatedProcessCount();
 
@@ -413,6 +413,10 @@ bool Device::createEngines() {
                     gfxCoreHelper.adjustCopyEngineRegularContextCount(engineGroup->engines.size(), contextCount);
                 }
             }
+
+            if (debugManager.flags.OverrideNumHighPriorityContexts.get() != -1) {
+                highPriorityContextCount = static_cast<uint32_t>(debugManager.flags.OverrideNumHighPriorityContexts.get());
+            }
             for (uint32_t engineIndex = 0; engineIndex < static_cast<uint32_t>(engineGroup->engines.size()); engineIndex++) {
                 auto engineType = engineGroup->engines[engineIndex].getEngineType();
 
@@ -565,7 +569,9 @@ bool Device::createEngine(EngineTypeUsage engineTypeUsage) {
     osContext->setContextGroupCount(useContextGroup ? gfxCoreHelper.getContextGroupContextsCount() : 0);
     osContext->setIsPrimaryEngine(isPrimaryEngine);
     osContext->setIsDefaultEngine(isDefaultEngine);
-
+    if (isPrimaryEngine) {
+        osContext->overridePriority(gfxCoreHelper.getLowestQueuePriorityLevel());
+    }
     DEBUG_BREAK_IF(getDeviceBitfield().count() > 1 && !osContext->isRootDevice());
 
     commandStreamReceiver->setupContext(*osContext);
@@ -749,7 +755,7 @@ Debugger *Device::getDebugger() const {
 }
 
 bool Device::areSharedSystemAllocationsAllowed() const {
-    if ((debugManager.flags.EnableRecoverablePageFaults.get() == 0) || (debugManager.flags.EnableSharedSystemUsmSupport.get() != 1)) {
+    if ((debugManager.flags.EnableRecoverablePageFaults.get() == 0) || (debugManager.flags.EnableSharedSystemUsmSupport.get() == 0)) {
         return false;
     }
     uint64_t mask = (UnifiedSharedMemoryFlags::access | UnifiedSharedMemoryFlags::atomicAccess | UnifiedSharedMemoryFlags::concurrentAccess | UnifiedSharedMemoryFlags::concurrentAtomicAccess);
@@ -1334,13 +1340,17 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
     } else {
         DEBUG_BREAK_IF(true);
     }
+
     if (priorityLevel.has_value()) {
         engines[secondaryEngineIndex].osContext->overridePriority(priorityLevel.value());
     }
-
+    if (debugManager.flags.PrintSecondaryContextEngineInfo.get()) {
+        std::stringstream contextEngineInfo;
+        contextEngineInfo << "SecondaryContexts::getEngine-> engineUsage: " << EngineHelpers::engineUsageToString(usage).c_str() << " index: " << secondaryEngineIndex << " priorityLevel: " << (engines[secondaryEngineIndex].osContext->hasPriorityLevel() ? std::to_string(engines[secondaryEngineIndex].osContext->getPriorityLevel()) : "std::nullopt") << " \n";
+        PRINT_DEBUG_STRING(debugManager.flags.PrintSecondaryContextEngineInfo.get(), stdout, "%s", contextEngineInfo.str().c_str());
+    }
     return &engines[secondaryEngineIndex];
 }
-
 void Device::stopDirectSubmissionForCopyEngine() {
     auto internalBcsEngine = getInternalCopyEngine();
     if (internalBcsEngine == nullptr || getHardwareInfo().featureTable.ftrBcsInfo.count() > 1) {
