@@ -50,16 +50,17 @@ class ProductHelperHw : public ProductHelper {
     uint32_t getAubStreamSteppingFromHwRevId(const HardwareInfo &hwInfo) const override;
     std::optional<aub_stream::ProductFamily> getAubStreamProductFamily() const override;
     bool isDefaultEngineTypeAdjustmentRequired(const HardwareInfo &hwInfo) const override;
+    bool initializeInternalEngineImmediately() const override;
     bool isDisableOverdispatchAvailable(const HardwareInfo &hwInfo) const override;
     LocalMemoryAccessMode getLocalMemoryAccessMode(const HardwareInfo &hwInfo) const override;
     bool isNewResidencyModelSupported() const override;
-    bool isDirectSubmissionSupported(ReleaseHelper *releaseHelper) const override;
+    bool isDirectSubmissionSupported() const override;
     bool isDirectSubmissionConstantCacheInvalidationNeeded(const HardwareInfo &hwInfo) const override;
     bool restartDirectSubmissionForHostptrFree() const override;
     std::pair<bool, bool> isPipeControlPriorToNonPipelinedStateCommandsWARequired(const HardwareInfo &hwInfo, bool isRcs, const ReleaseHelper *releaseHelper) const override;
     bool heapInLocalMem(const HardwareInfo &hwInfo) const override;
     void setCapabilityCoherencyFlag(const HardwareInfo &hwInfo, bool &coherencyFlag) const override;
-    bool canShareMemoryWithoutNTHandle() const override;
+    uint32_t canShareMemoryWithoutNTHandle() const override;
     bool isAdditionalMediaSamplerProgrammingRequired() const override;
     bool isInitialFlagsProgrammingRequired() const override;
     bool isReturnedCmdSizeForMediaSamplerAdjustmentRequired() const override;
@@ -188,7 +189,6 @@ class ProductHelperHw : public ProductHelper {
     uint32_t getMaxLocalSubRegionSize(const HardwareInfo &hwInfo) const override;
     bool localDispatchSizeQuerySupported() const override;
     bool isDeviceToHostCopySignalingFenceRequired() const override;
-    size_t getMaxFillPatternSizeForCopyEngine() const override;
     bool isAvailableExtendedScratch() const override;
     std::optional<bool> isCoherentAllocation(uint64_t patIndex) const override;
     bool isStagingBuffersEnabled() const override;
@@ -199,6 +199,7 @@ class ProductHelperHw : public ProductHelper {
     uint32_t adjustMaxThreadsPerThreadGroup(uint32_t maxThreadsPerThreadGroup, uint32_t simt, uint32_t grfCount, bool isHeaplessModeEnabled) const override;
     uint64_t getPatIndex(CacheRegion cacheRegion, CachePolicy cachePolicy) const override;
     uint64_t getSharedSystemPatIndex() const override;
+    bool useSharedSystemUsm() const override;
     uint32_t getGmmResourceUsageOverride(uint32_t usageType) const override;
     bool isSharingWith3dOrMediaAllowed() const override;
     bool isL3FlushAfterPostSyncSupported(bool heaplessEnabled) const override;
@@ -214,8 +215,12 @@ class ProductHelperHw : public ProductHelper {
     bool isPidFdOrSocketForIpcSupported() const override;
     bool checkBcsForDirectSubmissionStop() const override;
     bool shouldRegisterEnqueuedWalkerWithProfiling() const override;
+    uint32_t getActualHwSlmSize(const RootDeviceEnvironment &rootDeviceEnvironment) const override;
     bool isInterruptSupported() const override;
     bool isCompressionFormatFromGmmRequired() const override;
+    bool isDeviceCapsReaderSupported() const override;
+    bool isMediaContextSupported() const override;
+    bool sipUsesSubslicePools() const override;
 
     ~ProductHelperHw() override = default;
 
