@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,10 +8,9 @@
 #pragma once
 #include "shared/source/helpers/driver_model_type.h"
 #include "shared/source/os_interface/os_interface.h"
+#include "shared/source/os_interface/windows/d3dkmthk_wrapper.h"
 #include "shared/source/os_interface/windows/windows_wrapper.h"
 
-#include <d3dkmthk.h>
-
 #include <memory>
 
 namespace NEO {
