@@ -9,9 +9,9 @@
 #include "shared/source/command_stream/aub_command_stream_receiver_hw_xehp_and_later.inl"
 #include "shared/source/helpers/array_count.h"
 #include "shared/source/helpers/populate_factory.h"
+#include "shared/source/xe2_hpg_core/hw_cmds_base.h"
 
 namespace NEO {
-struct Xe2HpgCoreFamily;
 
 using Family = Xe2HpgCoreFamily;
 static auto gfxCore = IGFX_XE2_HPG_CORE;
